# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 12
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 2

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtnetworkauth-everywhere-opensource-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtnetworkauth   %mklibname qt5networkauth %{qtmajor}
%define libqtnetworkauth_d %mklibname qt%{qtmajor}networkauth -d

Name:           qtnetworkauth5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Network Authenticators
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
BuildRequires:  qtbase5-devel >= %{version}

#Branch Patchs
# CVE-2024-36048 qtnetworkauth: badly seeded PRNG may result in guessable values
Patch1:         qtnetworkauth-fix-data-race-and-poor-seeding-in-generaterandomstring.patch

#Trunk Patchs

#Patch from Mageia

%description
Qt%{qtmajor} Network Authenticators; QtOAuth in particular.

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtNetworkAuth%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtNetworkAuth%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt5_docdir}/qtnetworkauth.qch
%{_qt5_docdir}/qtnetworkauth/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtnetworkauth}
Summary:        Qt%{qtmajor} NetworkAuth Component Library
Group:          System/Libraries

%description -n %{libqtnetworkauth}
Qt%{qtmajor} NetworkAuth Component Library.

Qt Network Authenticators; QtOAuth in particular.

%files -n %{libqtnetworkauth}
%{_qt5_libdir}/libQt5NetworkAuth.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtnetworkauth_d}
Summary:        Devel files needed to build apps based on QtNetworkAuth
Group:          Development/KDE and Qt
Requires:       %{libqtnetworkauth} = %{version}
Provides:       libqt5networkauth-devel = %{version}
Provides:       libqtnetworkauth5-devel = %{version}

%description -n %{libqtnetworkauth_d}
Devel files needed to build apps based on Qt NetworkAuth.

%files -n %{libqtnetworkauth_d}
%{_qt5_includedir}/QtNetworkAuth/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_networkauth.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_networkauth_private.pri
%{_qt5_libdir}/cmake/Qt5NetworkAuth/
%{_qt5_libdir}/libQt5NetworkAuth.prl
%{_qt5_libdir}/libQt5NetworkAuth.so
%{_qt5_libdir}/pkgconfig/Qt5NetworkAuth.pc
%{_qt5_examplesdir}/oauth/

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qtnetworkauth-everywhere-src-%{qtversion}

%build
%qmake_qt5
%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif

# .la and .a files, die, die, die.
find %{buildroot} -name '*.la' -delete


%changelog
* Mon May 27 2024 daviddavid <daviddavid> 5.15.12-2.mga10
+ Revision: 2068482
- add upstream patch to fix CVE-2024-36048 (mga#33247)

* Tue Jan 09 2024 neoclust <neoclust> 5.15.12-1.mga10
+ Revision: 2029326
- New version 5.15.12

* Fri Dec 09 2022 neoclust <neoclust> 5.15.7-1.mga9
+ Revision: 1920067
- New version 5.15.7

* Thu Sep 08 2022 neoclust <neoclust> 5.15.6-1.mga9
+ Revision: 1885953
- New version 5.15.6

* Sat Aug 27 2022 neoclust <neoclust> 5.15.5-1.mga9
+ Revision: 1881062
- New version 5.15.5

* Sun Apr 03 2022 umeabot <umeabot> 5.15.2-2.mga9
+ Revision: 1841981
- Mageia 9 Mass Rebuild

* Fri Dec 04 2020 daviddavid <daviddavid> 5.15.2-1.mga8
+ Revision: 1652458
- New version 5.15.2

* Sat Sep 12 2020 daviddavid <daviddavid> 5.15.1-1.mga8
+ Revision: 1624910
- New version 5.15.1

* Wed Jun 03 2020 daviddavid <daviddavid> 5.15.0-1.mga8
+ Revision: 1589823
- New version 5.15.0

* Thu Feb 20 2020 umeabot <umeabot> 5.14.1-2.mga8
+ Revision: 1545488
- Mageia 8 Mass Rebuild

* Tue Jan 28 2020 daviddavid <daviddavid> 5.14.1-1.mga8
+ Revision: 1484399
- New version 5.14.1

* Sun Sep 08 2019 neoclust <neoclust> 5.13.1-1.mga8
+ Revision: 1438492
- New version 5.13.1

* Sun Jul 14 2019 neoclust <neoclust> 5.13.0-2.mga8
+ Revision: 1421112
- Rebuild for new mkspecs macros

* Thu Jul 04 2019 daviddavid <daviddavid> 5.13.0-1.mga8
+ Revision: 1418154
- New version 5.13.0

* Mon Apr 01 2019 umeabot <umeabot> 5.12.2-2.mga7
+ Revision: 1384465
- Qt5 Rebuild

* Mon Mar 18 2019 neoclust <neoclust> 5.12.2-1.mga7
+ Revision: 1378538
- New version 5.12.2

* Fri Feb 01 2019 neoclust <neoclust> 5.12.1-1.mga7
+ Revision: 1362283
- New version 5.12.1

* Thu Dec 13 2018 neoclust <neoclust> 5.12.0-1.mga7
+ Revision: 1340896
- New version 5.12.0

* Tue Oct 09 2018 neoclust <neoclust> 5.11.2-1.mga7
+ Revision: 1319027
- New version 5.11.2

* Sun Sep 23 2018 umeabot <umeabot> 5.11.1-2.mga7
+ Revision: 1300713
- Mageia 7 Mass Rebuild

* Sun Jul 29 2018 neoclust <neoclust> 5.11.1-1.mga7
+ Revision: 1245814
- New version 5.11.1

* Mon May 28 2018 neoclust <neoclust> 5.11.0-1.mga7
+ Revision: 1232715
- New version 5.11.0

* Thu Apr 12 2018 neoclust <neoclust> 5.10.1-1.mga7
+ Revision: 1217972
- New version 5.10.1

* Wed Feb 28 2018 neoclust <neoclust> 5.9.4-1.mga7
+ Revision: 1205680
- New version 5.9.4

* Wed Dec 27 2017 neoclust <neoclust> 5.9.3-1.mga7
+ Revision: 1185615
- New version 5.9.3

* Sat Jul 22 2017 neoclust <neoclust> 5.9.1-1.mga7
+ Revision: 1128159
- imported package qtnetworkauth5

